@@ -303,13 +303,31 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         return self
 
     def update_operation(
-        self: ThisResolverType, /, _: T.Optional[UpdateOperation]
+        self: ThisResolverType,
+        operation: UpdateOperation = None,
+        *,
+        add: bool = None,
+        replace: bool = None,
+        remove: bool = None,
     ) -> ThisResolverType:
         if self._update_operation:
             raise ResolverException(
                 f"update_operation of {self._update_operation} has already been provided."
             )
-        self._update_operation = _
+        if operation:
+            self._update_operation = operation
+            return self
+        if len([None for _ in [add, replace, remove] if _ is None]) != 2:
+            raise ResolverException("Must give exactly one update operation")
+        if add:
+            opp = UpdateOperation.ADD
+        elif replace:
+            opp = UpdateOperation.REPLACE
+        elif remove:
+            opp = UpdateOperation.REMOVE
+        else:
+            raise ResolverException("Must provide an update operation")
+        self._update_operation = opp
         return self
 
     """QUERY STRING"""
